@@ -1,11 +1,12 @@
 use crate::{docker, error::Error, rancher, types::cli::Restart, util};
 use anyhow::Result;
+use log::info;
 
 pub async fn restart(opt: &Restart, docker_socket_path: Option<String>) -> Result<()> {
     let docker = docker::docker_client(docker_socket_path).await?;
     match rancher::is_bovine(&docker.inspect_container(&opt.container_id, None).await?)? {
         true => {
-            println!("Restarting Rancher container: {}", &opt.container_id);
+            info!("Restarting Rancher container: {}", &opt.container_id);
             match docker.restart_container(&opt.container_id, None).await {
                 Ok(_) => Ok(()),
                 Err(e) => {
