@@ -1,6 +1,7 @@
+use crate::error::Error;
 use anyhow::Result;
 use clap::Clap;
-use std::env;
+use std::{env, io::Write};
 use types::cli::{Opt, SubCommand};
 
 mod commands;
@@ -16,14 +17,20 @@ async fn main() -> Result<()> {
     let opt = Opt::parse();
     if opt.debug {
         env::set_var("RUST_LOG", "debug");
+        env_logger::init();
     } else if env::var("RUST_LOG").is_err() {
-        env::set_var("RUST_LOG", "OFF");
+        env::set_var("RUST_LOG", "info");
+        // Since we are using `INFO` logs for user messages, we want to print to STDOUT and not STDERR.
+        env_logger::builder()
+            .format(|buf, record| writeln!(buf, "{}", record.args()))
+            .target(env_logger::Target::Stdout)
+            .init();
     }
-    env_logger::init();
 
     match opt.subcmd {
         SubCommand::Get(o) => commands::get::get(&o, opt.docker_socket_path).await?,
         SubCommand::List(o) => commands::list::list(&o, opt.docker_socket_path).await?,
+        SubCommand::Logs(_) if opt.debug => return Err(Error::LogsDebugModeEnabled.into()),
         SubCommand::Logs(o) => commands::logs::logs(&o, opt.docker_socket_path).await?,
         SubCommand::Restart(o) => commands::restart::restart(&o, opt.docker_socket_path).await?,
         SubCommand::Run(o) => commands::run::run(&o, opt.docker_socket_path).await?,
